@@ -828,9 +828,9 @@ meta_window_actor_get_x_window (MetaWindowActor *self)
 /**
  * meta_window_actor_get_meta_window:
  *
- * Gets the MetaWindow object that the the MetaWindowActor is displaying
+ * Gets the #MetaWindow object that the the #MetaWindowActor is displaying
  *
- * Return value: (transfer none): the displayed MetaWindow
+ * Return value: (transfer none): the displayed #MetaWindow
  */
 MetaWindow *
 meta_window_actor_get_meta_window (MetaWindowActor *self)
@@ -843,7 +843,7 @@ meta_window_actor_get_meta_window (MetaWindowActor *self)
  *
  * Gets the ClutterActor that is used to display the contents of the window
  *
- * Return value: (transfer none): the ClutterActor for the contents
+ * Return value: (transfer none): the #ClutterActor for the contents
  */
 ClutterActor *
 meta_window_actor_get_texture (MetaWindowActor *self)
@@ -958,6 +958,9 @@ meta_window_actor_damage_all (MetaWindowActor *self)
                 "pixmap-height", &pixmap_height,
                 NULL);
 
+  if (!priv->mapped || priv->needs_pixmap)
+    return;
+
   clutter_x11_texture_pixmap_update_area (texture_x11,
                                           0,
                                           0,
@@ -1217,8 +1220,9 @@ meta_window_actor_should_unredirect (MetaWindowActor *self)
 {
   MetaWindow *metaWindow = meta_window_actor_get_meta_window (self);
   MetaScreen *screen = meta_window_get_screen (metaWindow);
+  MetaWindowActorPrivate *priv = self->priv;
 
-  if (meta_window_is_override_redirect (metaWindow) && self->priv->opacity == 0xff)
+  if (meta_window_is_override_redirect (metaWindow) && priv->opacity == 0xff && !priv->argb32)
     {
       int screen_width, screen_height;
       MetaRectangle window_rect;
@@ -1804,7 +1808,7 @@ meta_window_actor_set_visible_region_beneath (MetaWindowActor *self,
  * @self: a #MetaWindowActor
  *
  * Unsets the regions set by meta_window_actor_reset_visible_region() and
- *meta_window_actor_reset_visible_region_beneath()
+ * meta_window_actor_reset_visible_region_beneath()
  */
 void
 meta_window_actor_reset_visible_regions (MetaWindowActor *self)
@@ -2028,6 +2032,8 @@ meta_window_actor_process_damage (MetaWindowActor    *self,
       return;
     }
 
+  if (!priv->mapped || priv->needs_pixmap)
+    return;
 
   clutter_x11_texture_pixmap_update_area (texture_x11,
                                           event->area.x,
